# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlSchoorhoek(KeuzelijstField):
    """De schoorhoek van het object, uitgedrukt in 1 op x (vb.: 1/4)."""
    naam = 'KlSchoorhoek'
    label = 'Schoorhoek'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/implementatieelement#KlSchoorhoek'
    definition = 'De schoorhoek van het object, uitgedrukt in 1 op x (vb.: 1/4).'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlSchoorhoek'
    options = {
        '1-20': KeuzelijstWaarde(invulwaarde='1-20',
                                 label='1/20',
                                 status='ingebruik',
                                 definitie='Een schoorhoek van 1 op 20.',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSchoorhoek/1-20'),
        '1-3': KeuzelijstWaarde(invulwaarde='1-3',
                                label='1/3',
                                status='ingebruik',
                                definitie='Een schoorhoek van 1 op 3.',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSchoorhoek/1-3'),
        '1-4': KeuzelijstWaarde(invulwaarde='1-4',
                                label='1/4',
                                status='ingebruik',
                                definitie='Een schoorhoek van 1 op 4.',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSchoorhoek/1-4'),
        '1-5': KeuzelijstWaarde(invulwaarde='1-5',
                                label='1/5',
                                status='ingebruik',
                                definitie='Een schoorhoek van 1 op 5.',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSchoorhoek/1-5')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.Onderdeel.Ruigte import Ruigte
from ...Datatypes.KlNSB import KlNSB


# Generated with OTLClassCreator. To modify: extend, do not edit
class NatteRuigte(Ruigte):
    """Een natte ruigte is een vegetatie op natte standplaatsen die ontstaat na het wegvallen van beheer (maaien of begrazen) en dat gepaard gaat met de vestiging en/of uitbreiding van forse plantensoorten (zogenaamde ruigtekruiden). Deze ruigtekruiden zijn gekenmerkt door hun overblijvende natuur, hun snelle groei en de productie van aanzienlijke hoeveelheden strooisel, waardoor ze andere, vooral kleinere soorten, verdringen en de vestiging van andere soorten verhinderen."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#NatteRuigte'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self._huidigNatuurbeeld = OTLAttribuut(field=KlNSB,
                                               naam='huidigNatuurbeeld',
                                               label='huidig natuurbeeld',
                                               objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#NatteRuigte.huidigNatuurbeeld',
                                               definition='Bepaling van het vegetatietype op basis van terreininventarisatie.',
                                               owner=self)

    @property
    def huidigNatuurbeeld(self) -> str:
        """Bepaling van het vegetatietype op basis van terreininventarisatie."""
        return self._huidigNatuurbeeld.get_waarde()

    @huidigNatuurbeeld.setter
    def huidigNatuurbeeld(self, value):
        self._huidigNatuurbeeld.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from abc import abstractmethod
from ...Classes.Abstracten.Signalisatie import Signalisatie
from ...Classes.ImplementatieElement.AIMObject import AIMObject
from otlmow_model.OtlmowModel.BaseClasses.BooleanField import BooleanField
from ...Datatypes.DtcMarkeringOpvatting import DtcMarkeringOpvatting, DtcMarkeringOpvattingWaarden
from ...Datatypes.DtcProductidentificatiecode import DtcProductidentificatiecode, DtcProductidentificatiecodeWaarden
from ...Datatypes.KlKleurMarkering import KlKleurMarkering
from ...Datatypes.KlMarkeringSoort import KlMarkeringSoort


# Generated with OTLClassCreator. To modify: extend, do not edit
class Markering(Signalisatie, AIMObject):
    """Abstracte als noemer voor de verschillende types van markeringen."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Markering'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    @abstractmethod
    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#AndereLaag', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#AndereVerharding', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#ArtificieleLaag', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Bestrating', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Laag', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#LaagBouwklasse', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Afdichting', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Asfaltmat', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#BeschermingWapening', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Beschermlaag', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#BestratingVanBetonstraatsteen', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#BestratingVanBetontegel', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#BestratingVanGebakkenStraatsteen', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#BestratingVanGrasbetontegel', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#BestratingVanKassei', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#BestratingVanMozaiekkei', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#BestratingVanNatuursteentegel', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bestrijking', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Betonmat', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Betonmatras', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#BitumineuzeLaag', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Cementbetonverharding', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#ColloidaalBeton', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Dolomietverharding', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Draineerlaag', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#DunneOverlaging', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#GeexpandeerdPolystyreen', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Geotextiel', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Grond', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Noppendrainage', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#OnbegroeidVoorkomen', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Onderbouw', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Schanskorf', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#ScheurremmendeLaag', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Slemlaag', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Steenslagverharding', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Stortdraad', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Stortsteen', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Ternairmengselverharding', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#VerhardingGrasKunststofplaat', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Walsbetonverharding', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#WaterdoorlatendeBestrating', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Wiepenmat', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#IsInspectieVan', target='https://wegenenverkeer.data.vlaanderen.be/ns/proefenmeting#ProefLuminantie', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#IsInspectieVan', target='https://wegenenverkeer.data.vlaanderen.be/ns/proefenmeting#ProefStroefheid', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#IsInspectieVan', target='https://wegenenverkeer.data.vlaanderen.be/ns/proefenmeting#ProefZichtbaarheidBijDagOfWV', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#IsInspectieVan', target='https://wegenenverkeer.data.vlaanderen.be/ns/proefenmeting#ProefZichtbaarheidBijNacht', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#IsInspectieVan', target='https://wegenenverkeer.data.vlaanderen.be/ns/proefenmeting#ProefZichtbaarheidBijNachtNatWegdek', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#IsInspectieVan', target='https://wegenenverkeer.data.vlaanderen.be/ns/proefenmeting#ProefZichtbaarheidBijNachtRegenweer', direction='i')  # i = direction: incoming

        self._isHandwerk = OTLAttribuut(field=BooleanField,
                                        naam='isHandwerk',
                                        label='is handwerk',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Markering.isHandwerk',
                                        definition='Boolean om te bepalen of de markering machinaal of handmatig is aangebracht.',
                                        owner=self)

        self._isTijdelijk = OTLAttribuut(field=BooleanField,
                                         naam='isTijdelijk',
                                         label='is tijdelijk',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Markering.isTijdelijk',
                                         definition='Aanduiding of de wegmarkering al dan niet tot de werfsignalisatie behoort.',
                                         owner=self)

        self._kleur = OTLAttribuut(field=KlKleurMarkering,
                                   naam='kleur',
                                   label='kleur',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Markering.kleur',
                                   definition='De kleur van de gebruikte markering.',
                                   owner=self)

        self._markeringsoort = OTLAttribuut(field=KlMarkeringSoort,
                                            naam='markeringsoort',
                                            label='markeringsoort',
                                            objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Markering.markeringsoort',
                                            definition='De soort van markering (verf, thermopast,...).',
                                            owner=self)

        self._markeringsysteemCopro = OTLAttribuut(field=DtcProductidentificatiecode,
                                                   naam='markeringsysteemCopro',
                                                   label='markeringsysteem COPRO',
                                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Markering.markeringsysteemCopro',
                                                   definition='De product informatie van de markering via COPRO codes.',
                                                   owner=self)

        self._opvatting = OTLAttribuut(field=DtcMarkeringOpvatting,
                                       naam='opvatting',
                                       label='opvatting',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Markering.opvatting',
                                       definition='De opvatting van de markering, zijnde middelenverbintenis of resultaatsverbintenis met een minimale levensduur.',
                                       owner=self)

    @property
    def isHandwerk(self) -> bool:
        """Boolean om te bepalen of de markering machinaal of handmatig is aangebracht."""
        return self._isHandwerk.get_waarde()

    @isHandwerk.setter
    def isHandwerk(self, value):
        self._isHandwerk.set_waarde(value, owner=self)

    @property
    def isTijdelijk(self) -> bool:
        """Aanduiding of de wegmarkering al dan niet tot de werfsignalisatie behoort."""
        return self._isTijdelijk.get_waarde()

    @isTijdelijk.setter
    def isTijdelijk(self, value):
        self._isTijdelijk.set_waarde(value, owner=self)

    @property
    def kleur(self) -> str:
        """De kleur van de gebruikte markering."""
        return self._kleur.get_waarde()

    @kleur.setter
    def kleur(self, value):
        self._kleur.set_waarde(value, owner=self)

    @property
    def markeringsoort(self) -> str:
        """De soort van markering (verf, thermopast,...)."""
        return self._markeringsoort.get_waarde()

    @markeringsoort.setter
    def markeringsoort(self, value):
        self._markeringsoort.set_waarde(value, owner=self)

    @property
    def markeringsysteemCopro(self) -> DtcProductidentificatiecodeWaarden:
        """De product informatie van de markering via COPRO codes."""
        return self._markeringsysteemCopro.get_waarde()

    @markeringsysteemCopro.setter
    def markeringsysteemCopro(self, value):
        self._markeringsysteemCopro.set_waarde(value, owner=self)

    @property
    def opvatting(self) -> DtcMarkeringOpvattingWaarden:
        """De opvatting van de markering, zijnde middelenverbintenis of resultaatsverbintenis met een minimale levensduur."""
        return self._opvatting.get_waarde()

    @opvatting.setter
    def opvatting(self, value):
        self._opvatting.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlLokaalTerreinType(KeuzelijstField):
    """Lokale terrein types."""
    naam = 'KlLokaalTerreinType'
    label = 'Lokaal terreintype'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/installatie#KlLokaalTerreinType'
    definition = 'Lokale terrein types.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlLokaalTerreinType'
    options = {
        'andere-gelieve-te-omschrijven-in-extra-notitie-voor-het-object': KeuzelijstWaarde(invulwaarde='andere-gelieve-te-omschrijven-in-extra-notitie-voor-het-object',
                                                                                           label='Andere (gelieve te omschrijven in extra notitie voor het object)',
                                                                                           status='ingebruik',
                                                                                           definitie='Andere (gelieve te omschrijven in extra notitie voor het object)',
                                                                                           objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLokaalTerreinType/andere-gelieve-te-omschrijven-in-extra-notitie-voor-het-object'),
        'bergachtig-en-overwegend-bomen-struiken': KeuzelijstWaarde(invulwaarde='bergachtig-en-overwegend-bomen-struiken',
                                                                    label='Bergachtig en overwegend bomen / struiken',
                                                                    status='ingebruik',
                                                                    definitie='Bergachtig en overwegend bomen / struiken',
                                                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLokaalTerreinType/bergachtig-en-overwegend-bomen-struiken'),
        'bergachtig-verspreid-bomen-struiken': KeuzelijstWaarde(invulwaarde='bergachtig-verspreid-bomen-struiken',
                                                                label='Bergachtig verspreid bomen / struiken',
                                                                status='ingebruik',
                                                                definitie='Bergachtig verspreid bomen / struiken',
                                                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLokaalTerreinType/bergachtig-verspreid-bomen-struiken'),
        'bergachtig-zonder-bomen': KeuzelijstWaarde(invulwaarde='bergachtig-zonder-bomen',
                                                    label='Bergachtig zonder bomen',
                                                    status='ingebruik',
                                                    definitie='Bergachtig zonder bomen',
                                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLokaalTerreinType/bergachtig-zonder-bomen'),
        'golvend-en-overwegend-bomen-struiken': KeuzelijstWaarde(invulwaarde='golvend-en-overwegend-bomen-struiken',
                                                                 label='Golvend en overwegend bomen / struiken',
                                                                 status='ingebruik',
                                                                 definitie='Golvend en overwegend bomen / struiken',
                                                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLokaalTerreinType/golvend-en-overwegend-bomen-struiken'),
        'golvend-verspreid-bomen-struiken': KeuzelijstWaarde(invulwaarde='golvend-verspreid-bomen-struiken',
                                                             label='Golvend verspreid bomen / struiken',
                                                             status='ingebruik',
                                                             definitie='Golvend verspreid bomen / struiken',
                                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLokaalTerreinType/golvend-verspreid-bomen-struiken'),
        'golvend-zonder-bomen': KeuzelijstWaarde(invulwaarde='golvend-zonder-bomen',
                                                 label='Golvend zonder bomen',
                                                 status='ingebruik',
                                                 definitie='Golvend zonder bomen',
                                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLokaalTerreinType/golvend-zonder-bomen'),
        'vlak-en-overwegend-bomen-struiken': KeuzelijstWaarde(invulwaarde='vlak-en-overwegend-bomen-struiken',
                                                              label='Vlak en overwegend bomen / struiken',
                                                              status='ingebruik',
                                                              definitie='Vlak en overwegend bomen / struiken',
                                                              objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLokaalTerreinType/vlak-en-overwegend-bomen-struiken'),
        'vlak-en-verspreid-bomen-struiken': KeuzelijstWaarde(invulwaarde='vlak-en-verspreid-bomen-struiken',
                                                             label='Vlak en verspreid bomen / struiken',
                                                             status='ingebruik',
                                                             definitie='Vlak en verspreid bomen / struiken',
                                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLokaalTerreinType/vlak-en-verspreid-bomen-struiken'),
        'vlak-zonder-bomen': KeuzelijstWaarde(invulwaarde='vlak-zonder-bomen',
                                              label='Vlak zonder bomen',
                                              status='ingebruik',
                                              definitie='Vlak zonder bomen',
                                              objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLokaalTerreinType/vlak-zonder-bomen')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlSignaalkabelType(KeuzelijstField):
    """Lijst met types voor signalisatiekabels volgens de gebruikte materialen zoals opgenomen in het Standaarbestek 270."""
    naam = 'KlSignaalkabelType'
    label = 'Signalisatiekabel types'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlSignaalkabelType'
    definition = 'Lijst met types voor signalisatiekabels volgens de gebruikte materialen zoals opgenomen in het Standaarbestek 270.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlSignaalkabelType'
    options = {
        'coax': KeuzelijstWaarde(invulwaarde='coax',
                                 label='coax',
                                 status='ingebruik',
                                 definitie='coax',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelType/coax'),
        'coax-rg11': KeuzelijstWaarde(invulwaarde='coax-rg11',
                                      label='coax RG11',
                                      status='ingebruik',
                                      definitie='coax RG11',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelType/coax-rg11'),
        'coax-rg12': KeuzelijstWaarde(invulwaarde='coax-rg12',
                                      label='coax RG12',
                                      status='ingebruik',
                                      definitie='coax RG12',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelType/coax-rg12'),
        'coax-rg59': KeuzelijstWaarde(invulwaarde='coax-rg59',
                                      label='coax RG59',
                                      status='ingebruik',
                                      definitie='coax RG59',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelType/coax-rg59'),
        'elec': KeuzelijstWaarde(invulwaarde='elec',
                                 label='ELEC',
                                 status='ingebruik',
                                 definitie='ELEC',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelType/elec'),
        'emggb': KeuzelijstWaarde(invulwaarde='emggb',
                                  label='EmGGB',
                                  status='ingebruik',
                                  definitie='EmGGB',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelType/emggb'),
        'gefaradiseerde-kabel': KeuzelijstWaarde(invulwaarde='gefaradiseerde-kabel',
                                                 label='gefaradiseerde kabel',
                                                 status='ingebruik',
                                                 definitie='gefaradiseerde kabel',
                                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelType/gefaradiseerde-kabel'),
        'koperkabel': KeuzelijstWaarde(invulwaarde='koperkabel',
                                       label='koperkabel',
                                       status='ingebruik',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelType/koperkabel'),
        'li2ycy': KeuzelijstWaarde(invulwaarde='li2ycy',
                                   label='LI2YCY',
                                   status='ingebruik',
                                   definitie='LI2YCY',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelType/li2ycy'),
        'lihh-sh': KeuzelijstWaarde(invulwaarde='lihh-sh',
                                    label='Lihh-sh',
                                    status='ingebruik',
                                    definitie='Lihh-sh',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelType/lihh-sh'),
        'liy(st)yy': KeuzelijstWaarde(invulwaarde='liy(st)yy',
                                      label='LiY(st)YY',
                                      status='ingebruik',
                                      definitie='LiY(st)YY',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelType/liy(st)yy'),
        'liycy': KeuzelijstWaarde(invulwaarde='liycy',
                                  label='LIYCY',
                                  status='ingebruik',
                                  definitie='LIYCY',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelType/liycy'),
        'liycy(tp)': KeuzelijstWaarde(invulwaarde='liycy(tp)',
                                      label='LIYCY(TP)',
                                      status='ingebruik',
                                      definitie='LIYCY(TP)',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelType/liycy(tp)'),
        'liyy': KeuzelijstWaarde(invulwaarde='liyy',
                                 label='Liyy',
                                 status='ingebruik',
                                 definitie='Liyy',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelType/liyy'),
        'liyy-st-y': KeuzelijstWaarde(invulwaarde='liyy-st-y',
                                      label='Liyy(st)y',
                                      status='ingebruik',
                                      definitie='Liyy(st)y',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelType/liyy-st-y'),
        'olflex': KeuzelijstWaarde(invulwaarde='olflex',
                                   label='Olflex',
                                   status='ingebruik',
                                   definitie='Ölflex',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelType/olflex'),
        'profibuskabel': KeuzelijstWaarde(invulwaarde='profibuskabel',
                                          label='profibuskabel',
                                          status='ingebruik',
                                          objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelType/profibuskabel'),
        'svab': KeuzelijstWaarde(invulwaarde='svab',
                                 label='SVAB',
                                 status='ingebruik',
                                 definitie='SVAB',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelType/svab'),
        'svavb': KeuzelijstWaarde(invulwaarde='svavb',
                                  label='SVAVB',
                                  status='ingebruik',
                                  definitie='SVAVB',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelType/svavb'),
        'svavb-f2': KeuzelijstWaarde(invulwaarde='svavb-f2',
                                     label='SVAVB-F2',
                                     status='ingebruik',
                                     definitie='Gewapende signaalkabel voor ondergronds gebruik.',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelType/svavb-f2'),
        'svv-f2': KeuzelijstWaarde(invulwaarde='svv-f2',
                                   label='SVV-F2',
                                   status='ingebruik',
                                   definitie='Niet-gewapende signaalkabel voor binnen.',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelType/svv-f2'),
        'sxag-f2': KeuzelijstWaarde(invulwaarde='sxag-f2',
                                    label='SXAG-F2',
                                    status='ingebruik',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelType/sxag-f2'),
        'sxavb': KeuzelijstWaarde(invulwaarde='sxavb',
                                  label='SXAVB',
                                  status='ingebruik',
                                  definitie='Gewapende signaalkabel voor ondergronds gebruik.',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelType/sxavb'),
        'twavb': KeuzelijstWaarde(invulwaarde='twavb',
                                  label='TWAVB',
                                  status='ingebruik',
                                  definitie='TWAVB',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelType/twavb'),
        'uxl': KeuzelijstWaarde(invulwaarde='uxl',
                                label='UXL',
                                status='ingebruik',
                                definitie='UXL',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelType/uxl'),
        'xlpe': KeuzelijstWaarde(invulwaarde='xlpe',
                                 label='XLPE',
                                 status='ingebruik',
                                 definitie='XLPE',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelType/xlpe')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from otlmow_model.OtlmowModel.BaseClasses.WaardenObject import WaardenObject
from otlmow_model.OtlmowModel.BaseClasses.ComplexField import ComplexField
from ..Datatypes.KlConstructiestaalsoort import KlConstructiestaalsoort
from ..Datatypes.KlTypeVerankeringDekzerkprofiel import KlTypeVerankeringDekzerkprofiel


# Generated with OTLComplexDatatypeCreator. To modify: extend, do not edit
class DtcVerankeringDekzerkprofielWaarden(WaardenObject):
    def __init__(self):
        WaardenObject.__init__(self)
        self._materiaalVerankering = OTLAttribuut(field=KlConstructiestaalsoort,
                                                  naam='materiaalVerankering',
                                                  label='materiaal verankering',
                                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#DtcVerankeringDekzerkprofiel.materiaalVerankering',
                                                  definition='Het materiaal waaruit de verankering van het dekzerkprofiel bestaat.',
                                                  owner=self)

        self._typeVerankering = OTLAttribuut(field=KlTypeVerankeringDekzerkprofiel,
                                             naam='typeVerankering',
                                             label='type verankering',
                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#DtcVerankeringDekzerkprofiel.typeVerankering',
                                             definition='De verschillende opties van verankering voor dekzerkprofielen.',
                                             owner=self)

    @property
    def materiaalVerankering(self) -> str:
        """Het materiaal waaruit de verankering van het dekzerkprofiel bestaat."""
        return self._materiaalVerankering.get_waarde()

    @materiaalVerankering.setter
    def materiaalVerankering(self, value):
        self._materiaalVerankering.set_waarde(value, owner=self._parent)

    @property
    def typeVerankering(self) -> str:
        """De verschillende opties van verankering voor dekzerkprofielen."""
        return self._typeVerankering.get_waarde()

    @typeVerankering.setter
    def typeVerankering(self, value):
        self._typeVerankering.set_waarde(value, owner=self._parent)


# Generated with OTLComplexDatatypeCreator. To modify: extend, do not edit
class DtcVerankeringDekzerkprofiel(ComplexField):
    """Complexdatatype met informatie over de verankering van een dekzerkprofiel"""
    naam = 'DtcVerankeringDekzerkprofiel'
    label = 'verankering dekzerkprofiel'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#DtcVerankeringDekzerkprofiel'
    definition = 'Complexdatatype met informatie over de verankering van een dekzerkprofiel'
    waardeObject = DtcVerankeringDekzerkprofielWaarden

    def __str__(self):
        return ComplexField.__str__(self)




class CouldNotCreateInstanceError(ModuleNotFoundError):
    """
    Exception raised when an instance of a class could not be created.
    """
    def __init__(self, message: str, closest_matches: list[str] = None):
        super().__init__(message)
        self.message: str = message
        self.closest_matches: list[str] = closest_matches or []



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.ImplementatieElement.AIMNaamObject import AIMNaamObject
from otlmow_model.OtlmowModel.BaseClasses.BooleanField import BooleanField
from ...Datatypes.DtcDocument import DtcDocument, DtcDocumentWaarden
from ...Datatypes.KlTypeBrugdekvoeg import KlTypeBrugdekvoeg
from ...Datatypes.KlTypeVerankeringBrugdekvoeg import KlTypeVerankeringBrugdekvoeg
from ...Datatypes.KwantWrdInCentimeter import KwantWrdInCentimeter, KwantWrdInCentimeterWaarden
from ...Datatypes.KwantWrdInMeter import KwantWrdInMeter, KwantWrdInMeterWaarden
from otlmow_model.OtlmowModel.BaseClasses.StringField import StringField
from otlmow_model.OtlmowModel.GeometrieTypes.LijnGeometrie import LijnGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Brugdekvoeg(AIMNaamObject, LijnGeometrie):
    """Voegconstructie die dient om een opening te overbruggen. Voldoende vervormbaar om zich te kunnen aanpassen aan de bewegingen van de boorden en weerstandbiedend om belastingen te kunnen opvangen."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Brugdekvoeg'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Brugdeel', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Brugdek', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Kelderlandhoofd', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Kelderpijler', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Kokersectie', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Landhoofd', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Pijler', direction='u')  # u = unidirectional

        self._beschikbareVoegopening = OTLAttribuut(field=KwantWrdInCentimeter,
                                                    naam='beschikbareVoegopening',
                                                    label='beschikbare voegopening',
                                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Brugdekvoeg.beschikbareVoegopening',
                                                    definition='De beschikbare voegopening van de brugdekvoeg bij een gemiddelde temperatuur van 10 °C, uitgedrukt in centimeter.',
                                                    owner=self)

        self._detailplan = OTLAttribuut(field=DtcDocument,
                                        naam='detailplan',
                                        label='detailplan',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Brugdekvoeg.detailplan',
                                        definition='Het detailplan van de brugdekvoeg.',
                                        owner=self)

        self._heeftGeluidsreducerendElementen = OTLAttribuut(field=BooleanField,
                                                             naam='heeftGeluidsreducerendElementen',
                                                             label='heeft geluidsreducerend elementen',
                                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Brugdekvoeg.heeftGeluidsreducerendElementen',
                                                             definition='Geeft aan of de brugdekvoeg, al dan niet, geluidsreducerend elementen heeft.',
                                                             owner=self)

        self._lopendeMeterVoeg = OTLAttribuut(field=KwantWrdInMeter,
                                              naam='lopendeMeterVoeg',
                                              label='lopende meter voeg',
                                              objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Brugdekvoeg.lopendeMeterVoeg',
                                              definition='De lopende meter van de brugdekvoeg.',
                                              owner=self)

        self._producent = OTLAttribuut(field=StringField,
                                       naam='producent',
                                       label='producent',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Brugdekvoeg.producent',
                                       definition='De producent die de brugdekvoeg heeft gemaakt.',
                                       owner=self)

        self._typeBrugdekvoeg = OTLAttribuut(field=KlTypeBrugdekvoeg,
                                             naam='typeBrugdekvoeg',
                                             label='type brugdekvoeg',
                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Brugdekvoeg.typeBrugdekvoeg',
                                             definition='Het type van de brugdekvoeg.',
                                             owner=self)

        self._typeVerankering = OTLAttribuut(field=KlTypeVerankeringBrugdekvoeg,
                                             naam='typeVerankering',
                                             label='type verankering',
                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Brugdekvoeg.typeVerankering',
                                             definition='Het type van de verankering van de brugdekvoeg.',
                                             owner=self)

    @property
    def beschikbareVoegopening(self) -> KwantWrdInCentimeterWaarden:
        """De beschikbare voegopening van de brugdekvoeg bij een gemiddelde temperatuur van 10 °C, uitgedrukt in centimeter."""
        return self._beschikbareVoegopening.get_waarde()

    @beschikbareVoegopening.setter
    def beschikbareVoegopening(self, value):
        self._beschikbareVoegopening.set_waarde(value, owner=self)

    @property
    def detailplan(self) -> DtcDocumentWaarden:
        """Het detailplan van de brugdekvoeg."""
        return self._detailplan.get_waarde()

    @detailplan.setter
    def detailplan(self, value):
        self._detailplan.set_waarde(value, owner=self)

    @property
    def heeftGeluidsreducerendElementen(self) -> bool:
        """Geeft aan of de brugdekvoeg, al dan niet, geluidsreducerend elementen heeft."""
        return self._heeftGeluidsreducerendElementen.get_waarde()

    @heeftGeluidsreducerendElementen.setter
    def heeftGeluidsreducerendElementen(self, value):
        self._heeftGeluidsreducerendElementen.set_waarde(value, owner=self)

    @property
    def lopendeMeterVoeg(self) -> KwantWrdInMeterWaarden:
        """De lopende meter van de brugdekvoeg."""
        return self._lopendeMeterVoeg.get_waarde()

    @lopendeMeterVoeg.setter
    def lopendeMeterVoeg(self, value):
        self._lopendeMeterVoeg.set_waarde(value, owner=self)

    @property
    def producent(self) -> str:
        """De producent die de brugdekvoeg heeft gemaakt."""
        return self._producent.get_waarde()

    @producent.setter
    def producent(self, value):
        self._producent.set_waarde(value, owner=self)

    @property
    def typeBrugdekvoeg(self) -> str:
        """Het type van de brugdekvoeg."""
        return self._typeBrugdekvoeg.get_waarde()

    @typeBrugdekvoeg.setter
    def typeBrugdekvoeg(self, value):
        self._typeBrugdekvoeg.set_waarde(value, owner=self)

    @property
    def typeVerankering(self) -> str:
        """Het type van de verankering van de brugdekvoeg."""
        return self._typeVerankering.get_waarde()

    @typeVerankering.setter
    def typeVerankering(self, value):
        self._typeVerankering.set_waarde(value, owner=self)



# coding=utf-8
from typing import List
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.ImplementatieElement.AIMNaamObject import AIMNaamObject
from otlmow_model.OtlmowModel.BaseClasses.BooleanField import BooleanField
from ...Datatypes.KlGraadVanBeweegbaarheid import KlGraadVanBeweegbaarheid
from ...Datatypes.KlGraadVanStatischeBepaaldheid import KlGraadVanStatischeBepaaldheid
from ...Datatypes.KlMateriaalDragendeStructuurBrugdeel import KlMateriaalDragendeStructuurBrugdeel
from ...Datatypes.KlTypeBeweegbaarBrugdeel import KlTypeBeweegbaarBrugdeel
from ...Datatypes.KlTypeBrugdeel import KlTypeBrugdeel
from ...Datatypes.KwantWrdInKiloNewton import KwantWrdInKiloNewton, KwantWrdInKiloNewtonWaarden
from ...Datatypes.KwantWrdInMeter import KwantWrdInMeter, KwantWrdInMeterWaarden
from ...Datatypes.KwantWrdInVierkanteMeter import KwantWrdInVierkanteMeter, KwantWrdInVierkanteMeterWaarden
from otlmow_model.OtlmowModel.BaseClasses.NonNegIntegerField import NonNegIntegerField
from otlmow_model.OtlmowModel.GeometrieTypes.VlakGeometrie import VlakGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Brugdeel(AIMNaamObject, VlakGeometrie):
    """Het deel dat je kan wegnemen van een brug in zijn geheel. Dit kan ook meerdere overspanningen hebben. In het geval van beweegbare bruggen worden de onderdelen die de beweging mogelijk maken zoals balansarmen, tegengewicht, hameipoort,..etc ook gevat in het object brugdeel."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Brugdeel'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#AanhorighedenBrug', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Verlichtingstoestel', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Pijler', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Trekker', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Brugdekvoeg', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Centreerinrichting', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Stootblok', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Trillingsvoorziening', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Balans', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Balk', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Boog', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Brug', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Brugdek', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Brugligger', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Damwand', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#ExterneNaspanning', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Gewelf', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Hameipoort', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Hameistijl', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Hanger', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Hefportiek', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Heftoren', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#HorizontaleConstructieplaat', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Kolom', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Pyloon', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Randprofiel', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Trekker', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#VakwerkElement', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Wand', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Windverband', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Draagkabel', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Funderingspaal', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#RegelbaarTegengewicht', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#VastTegengewicht', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Vlotplaat', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#LigtOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Brugballast', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#LigtOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Oplegrij', direction='o')  # o = direction: outgoing

        self._aantalOverspanningen = OTLAttribuut(field=NonNegIntegerField,
                                                  naam='aantalOverspanningen',
                                                  label='aantal overspanningen',
                                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Brugdeel.aantalOverspanningen',
                                                  definition='Aantal overspanningen, van oplegging naar volgende oplegging (bij een isostatisch brugdeel zal dit één overspanning zijn, bij een hyperstatisch brugdeel zijn dit er meerdere).',
                                                  owner=self)

        self._graadVanBeweegbaarheid = OTLAttribuut(field=KlGraadVanBeweegbaarheid,
                                                    naam='graadVanBeweegbaarheid',
                                                    label='graad van beweegbaarheid',
                                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Brugdeel.graadVanBeweegbaarheid',
                                                    definition='De manier waarop het brugdeel beweegt.',
                                                    owner=self)

        self._graadVanStatischeBepaaldheid = OTLAttribuut(field=KlGraadVanStatischeBepaaldheid,
                                                          naam='graadVanStatischeBepaaldheid',
                                                          label='graad van statische bepaaldheid',
                                                          objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Brugdeel.graadVanStatischeBepaaldheid',
                                                          definition='Welke statische bepaaldheid het brugdeel heeft.',
                                                          owner=self)

        self._heeftVoorzieningNegatieveReactie = OTLAttribuut(field=BooleanField,
                                                              naam='heeftVoorzieningNegatieveReactie',
                                                              label='heeft voorziening negatieve reactie',
                                                              objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Brugdeel.heeftVoorzieningNegatieveReactie',
                                                              definition='Geeft aan of het brugdeel een voorziening negatieve reactie bevat, al dan niet.',
                                                              owner=self)

        self._individueleAfstandOverspanningen = OTLAttribuut(field=KwantWrdInMeter,
                                                              naam='individueleAfstandOverspanningen',
                                                              label='individuele afstand overspanningen',
                                                              objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Brugdeel.individueleAfstandOverspanningen',
                                                              kardinaliteit_max='*',
                                                              definition='De individuele afstand tussen opeenvolgende opleggingen, in meter. Dit wordt uitgedrukt gaande van LO naar RO, of in oplopende kilometerpunten. Er kunnen meerdere waarden mogelijk zijn (vb.: voor hyperstatische brugdelen).',
                                                              owner=self)

        self._materiaalDragendeStructuur = OTLAttribuut(field=KlMateriaalDragendeStructuurBrugdeel,
                                                        naam='materiaalDragendeStructuur',
                                                        label='materiaal dragende structuur',
                                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Brugdeel.materiaalDragendeStructuur',
                                                        definition='Het materiaal van de dragende structuur van het brugdeel.',
                                                        owner=self)

        self._totaleBreedteBrugdeel = OTLAttribuut(field=KwantWrdInMeter,
                                                   naam='totaleBreedteBrugdeel',
                                                   label='totale breedte brugdeel',
                                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Brugdeel.totaleBreedteBrugdeel',
                                                   definition='De totale breedte van het brugdeel, uitgedrukt in meter.',
                                                   owner=self)

        self._totaleLengteBrugdeel = OTLAttribuut(field=KwantWrdInMeter,
                                                  naam='totaleLengteBrugdeel',
                                                  label='totale lengte brugdeel',
                                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Brugdeel.totaleLengteBrugdeel',
                                                  definition='De totale lengte van voeg tot voeg van het brugdeel, uitgedrukt in meter.',
                                                  owner=self)

        self._totaleOppervlakteBrugdeel = OTLAttribuut(field=KwantWrdInVierkanteMeter,
                                                       naam='totaleOppervlakteBrugdeel',
                                                       label='totale oppervlakte brugdeel',
                                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Brugdeel.totaleOppervlakteBrugdeel',
                                                       definition='De totale oppervlakte van het gehele brugdeel (van hetzelfde type), uitgedrukt in vierkante meter.',
                                                       owner=self)

        self._totaleSpankracht = OTLAttribuut(field=KwantWrdInKiloNewton,
                                              naam='totaleSpankracht',
                                              label='totale spankracht',
                                              objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Brugdeel.totaleSpankracht',
                                              definition='De totale spankracht van het brugdeel, uitgedrukt in kiloNewton.',
                                              owner=self)

        self._typeBeweegbaarBrugdeel = OTLAttribuut(field=KlTypeBeweegbaarBrugdeel,
                                                    naam='typeBeweegbaarBrugdeel',
                                                    label='type beweegbaar brugdeel',
                                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Brugdeel.typeBeweegbaarBrugdeel',
                                                    definition='Het type van het beweegbaar brugdeel.',
                                                    owner=self)

        self._typeBrugdeel = OTLAttribuut(field=KlTypeBrugdeel,
                                          naam='typeBrugdeel',
                                          label='type brugdeel',
                                          objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Brugdeel.typeBrugdeel',
                                          definition='Het type brugdeel.',
                                          owner=self)

    @property
    def aantalOverspanningen(self) -> int:
        """Aantal overspanningen, van oplegging naar volgende oplegging (bij een isostatisch brugdeel zal dit één overspanning zijn, bij een hyperstatisch brugdeel zijn dit er meerdere)."""
        return self._aantalOverspanningen.get_waarde()

    @aantalOverspanningen.setter
    def aantalOverspanningen(self, value):
        self._aantalOverspanningen.set_waarde(value, owner=self)

    @property
    def graadVanBeweegbaarheid(self) -> str:
        """De manier waarop het brugdeel beweegt."""
        return self._graadVanBeweegbaarheid.get_waarde()

    @graadVanBeweegbaarheid.setter
    def graadVanBeweegbaarheid(self, value):
        self._graadVanBeweegbaarheid.set_waarde(value, owner=self)

    @property
    def graadVanStatischeBepaaldheid(self) -> str:
        """Welke statische bepaaldheid het brugdeel heeft."""
        return self._graadVanStatischeBepaaldheid.get_waarde()

    @graadVanStatischeBepaaldheid.setter
    def graadVanStatischeBepaaldheid(self, value):
        self._graadVanStatischeBepaaldheid.set_waarde(value, owner=self)

    @property
    def heeftVoorzieningNegatieveReactie(self) -> bool:
        """Geeft aan of het brugdeel een voorziening negatieve reactie bevat, al dan niet."""
        return self._heeftVoorzieningNegatieveReactie.get_waarde()

    @heeftVoorzieningNegatieveReactie.setter
    def heeftVoorzieningNegatieveReactie(self, value):
        self._heeftVoorzieningNegatieveReactie.set_waarde(value, owner=self)

    @property
    def individueleAfstandOverspanningen(self) -> List[KwantWrdInMeterWaarden]:
        """De individuele afstand tussen opeenvolgende opleggingen, in meter. Dit wordt uitgedrukt gaande van LO naar RO, of in oplopende kilometerpunten. Er kunnen meerdere waarden mogelijk zijn (vb.: voor hyperstatische brugdelen)."""
        return self._individueleAfstandOverspanningen.get_waarde()

    @individueleAfstandOverspanningen.setter
    def individueleAfstandOverspanningen(self, value):
        self._individueleAfstandOverspanningen.set_waarde(value, owner=self)

    @property
    def materiaalDragendeStructuur(self) -> str:
        """Het materiaal van de dragende structuur van het brugdeel."""
        return self._materiaalDragendeStructuur.get_waarde()

    @materiaalDragendeStructuur.setter
    def materiaalDragendeStructuur(self, value):
        self._materiaalDragendeStructuur.set_waarde(value, owner=self)

    @property
    def totaleBreedteBrugdeel(self) -> KwantWrdInMeterWaarden:
        """De totale breedte van het brugdeel, uitgedrukt in meter."""
        return self._totaleBreedteBrugdeel.get_waarde()

    @totaleBreedteBrugdeel.setter
    def totaleBreedteBrugdeel(self, value):
        self._totaleBreedteBrugdeel.set_waarde(value, owner=self)

    @property
    def totaleLengteBrugdeel(self) -> KwantWrdInMeterWaarden:
        """De totale lengte van voeg tot voeg van het brugdeel, uitgedrukt in meter."""
        return self._totaleLengteBrugdeel.get_waarde()

    @totaleLengteBrugdeel.setter
    def totaleLengteBrugdeel(self, value):
        self._totaleLengteBrugdeel.set_waarde(value, owner=self)

    @property
    def totaleOppervlakteBrugdeel(self) -> KwantWrdInVierkanteMeterWaarden:
        """De totale oppervlakte van het gehele brugdeel (van hetzelfde type), uitgedrukt in vierkante meter."""
        return self._totaleOppervlakteBrugdeel.get_waarde()

    @totaleOppervlakteBrugdeel.setter
    def totaleOppervlakteBrugdeel(self, value):
        self._totaleOppervlakteBrugdeel.set_waarde(value, owner=self)

    @property
    def totaleSpankracht(self) -> KwantWrdInKiloNewtonWaarden:
        """De totale spankracht van het brugdeel, uitgedrukt in kiloNewton."""
        return self._totaleSpankracht.get_waarde()

    @totaleSpankracht.setter
    def totaleSpankracht(self, value):
        self._totaleSpankracht.set_waarde(value, owner=self)

    @property
    def typeBeweegbaarBrugdeel(self) -> str:
        """Het type van het beweegbaar brugdeel."""
        return self._typeBeweegbaarBrugdeel.get_waarde()

    @typeBeweegbaarBrugdeel.setter
    def typeBeweegbaarBrugdeel(self, value):
        self._typeBeweegbaarBrugdeel.set_waarde(value, owner=self)

    @property
    def typeBrugdeel(self) -> str:
        """Het type brugdeel."""
        return self._typeBrugdeel.get_waarde()

    @typeBrugdeel.setter
    def typeBrugdeel(self, value):
        self._typeBrugdeel.set_waarde(value, owner=self)



# coding=utf-8
from datetime import time, time
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from otlmow_model.OtlmowModel.BaseClasses.WaardenObject import WaardenObject
from otlmow_model.OtlmowModel.BaseClasses.ComplexField import ComplexField
from ..Datatypes.KlAlgWeekdagen import KlAlgWeekdagen
from otlmow_model.OtlmowModel.BaseClasses.TimeField import TimeField


# Generated with OTLComplexDatatypeCreator. To modify: extend, do not edit
class DtcOpeningsurenSpecificatieWaarden(WaardenObject):
    def __init__(self):
        WaardenObject.__init__(self)
        self._openingstijd = OTLAttribuut(field=TimeField,
                                          naam='openingstijd',
                                          label='openingstijd',
                                          objectUri='https://schema.org/OpeningHoursSpecification.openingstijd',
                                          definition='Het tijdsstip waarop de opening plaatsvindt.',
                                          owner=self)

        self._sluitingstijd = OTLAttribuut(field=TimeField,
                                           naam='sluitingstijd',
                                           label='sluitingstijd',
                                           objectUri='https://schema.org/OpeningHoursSpecification.sluitingstijd',
                                           definition='Het tijdsstip waarop de sluiting plaatsvindt.',
                                           owner=self)

        self._weekdag = OTLAttribuut(field=KlAlgWeekdagen,
                                     naam='weekdag',
                                     label='weekdag',
                                     objectUri='https://schema.org/OpeningHoursSpecification.weekdag',
                                     definition='Een dag uit de week incl. weekenddagen.',
                                     owner=self)

    @property
    def openingstijd(self) -> time:
        """Het tijdsstip waarop de opening plaatsvindt."""
        return self._openingstijd.get_waarde()

    @openingstijd.setter
    def openingstijd(self, value):
        self._openingstijd.set_waarde(value, owner=self._parent)

    @property
    def sluitingstijd(self) -> time:
        """Het tijdsstip waarop de sluiting plaatsvindt."""
        return self._sluitingstijd.get_waarde()

    @sluitingstijd.setter
    def sluitingstijd(self, value):
        self._sluitingstijd.set_waarde(value, owner=self._parent)

    @property
    def weekdag(self) -> str:
        """Een dag uit de week incl. weekenddagen."""
        return self._weekdag.get_waarde()

    @weekdag.setter
    def weekdag(self, value):
        self._weekdag.set_waarde(value, owner=self._parent)


# Generated with OTLComplexDatatypeCreator. To modify: extend, do not edit
class DtcOpeningsurenSpecificatie(ComplexField):
    """Complex datatype dat de openingsuren volgens https://schema.org/OpeningHoursSpecification specifieert."""
    naam = 'DtcOpeningsurenSpecificatie'
    label = 'Openingsurenspecificatie'
    objectUri = 'https://schema.org/OpeningHoursSpecification'
    definition = 'Complex datatype dat de openingsuren volgens https://schema.org/OpeningHoursSpecification specifieert.'
    waardeObject = DtcOpeningsurenSpecificatieWaarden

    def __str__(self):
        return ComplexField.__str__(self)




# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.Abstracten.Inloopbehuizing import Inloopbehuizing
from ...Classes.ImplementatieElement.NaampadObject import NaampadObject
from otlmow_model.OtlmowModel.BaseClasses.BooleanField import BooleanField
from ...Datatypes.KlCabineAardingsstelsel import KlCabineAardingsstelsel
from ...Datatypes.KlCabineStandaardtype import KlCabineStandaardtype
from ...Datatypes.KlNetwerklocatie import KlNetwerklocatie
from ...Datatypes.KwantWrdInMeter import KwantWrdInMeter, KwantWrdInMeterWaarden
from otlmow_model.OtlmowModel.GeometrieTypes.PuntGeometrie import PuntGeometrie
from otlmow_model.OtlmowModel.GeometrieTypes.VlakGeometrie import VlakGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Cabine(Inloopbehuizing, NaampadObject, PuntGeometrie, VlakGeometrie):
    """Een behuizing voornamelijk bestemd voor het beschermen van elektromechanische technieken waarin het omwille van de grootte en toegankelijkheid mogelijk is om rond te lopen."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Cabine'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Laag', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Toegangselement', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Aardingsinstallatie', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#EnergiemeterDNB', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HSBeveiligingscel', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Transformator', direction='u')  # u = unidirectional

        self._aardingsstelsel = OTLAttribuut(field=KlCabineAardingsstelsel,
                                             naam='aardingsstelsel',
                                             label='aardingsstelsel',
                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Cabine.aardingsstelsel',
                                             usagenote='Attribuut uit gebruik sinds versie 2.7.0 ',
                                             deprecated_version='2.7.0',
                                             definition='Keuze tussen verschillende types voor het gebruikte aardingsstelsel.',
                                             owner=self)

        self._heeftIsolatie = OTLAttribuut(field=BooleanField,
                                           naam='heeftIsolatie',
                                           label='heeft isolatie',
                                           objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Cabine.heeftIsolatie',
                                           definition='Geeft aan of de cabine is voorzien van isolatie.',
                                           owner=self)

        self._kelderdiepte = OTLAttribuut(field=KwantWrdInMeter,
                                          naam='kelderdiepte',
                                          label='kelderdiepte',
                                          objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Cabine.kelderdiepte',
                                          definition='Binnenhoogte in meter van de kabelkelder onder de cabine.',
                                          owner=self)

        self._standaardtype = OTLAttribuut(field=KlCabineStandaardtype,
                                           naam='standaardtype',
                                           label='standaardtype',
                                           objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Cabine.standaardtype',
                                           definition='Het type van de cabine volgens de gangbare standaarden.',
                                           owner=self)

        self._typeNetwerklocatie = OTLAttribuut(field=KlNetwerklocatie,
                                                naam='typeNetwerklocatie',
                                                label='keuzelijst netwerklocaties',
                                                objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Cabine.typeNetwerklocatie',
                                                definition='De verschillende opties netwerklocatie.',
                                                owner=self)

    @property
    def aardingsstelsel(self) -> str:
        """Keuze tussen verschillende types voor het gebruikte aardingsstelsel."""
        return self._aardingsstelsel.get_waarde()

    @aardingsstelsel.setter
    def aardingsstelsel(self, value):
        self._aardingsstelsel.set_waarde(value, owner=self)

    @property
    def heeftIsolatie(self) -> bool:
        """Geeft aan of de cabine is voorzien van isolatie."""
        return self._heeftIsolatie.get_waarde()

    @heeftIsolatie.setter
    def heeftIsolatie(self, value):
        self._heeftIsolatie.set_waarde(value, owner=self)

    @property
    def kelderdiepte(self) -> KwantWrdInMeterWaarden:
        """Binnenhoogte in meter van de kabelkelder onder de cabine."""
        return self._kelderdiepte.get_waarde()

    @kelderdiepte.setter
    def kelderdiepte(self, value):
        self._kelderdiepte.set_waarde(value, owner=self)

    @property
    def standaardtype(self) -> str:
        """Het type van de cabine volgens de gangbare standaarden."""
        return self._standaardtype.get_waarde()

    @standaardtype.setter
    def standaardtype(self, value):
        self._standaardtype.set_waarde(value, owner=self)

    @property
    def typeNetwerklocatie(self) -> str:
        """De verschillende opties netwerklocatie."""
        return self._typeNetwerklocatie.get_waarde()

    @typeNetwerklocatie.setter
    def typeNetwerklocatie(self, value):
        self._typeNetwerklocatie.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.Abstracten.ConstructiefObject import ConstructiefObject
from ...Datatypes.DtcDocument import DtcDocument, DtcDocumentWaarden
from ...Datatypes.KlTypeBrugligger import KlTypeBrugligger
from ...Datatypes.KlTypeDoorsnede import KlTypeDoorsnede
from otlmow_model.OtlmowModel.BaseClasses.NonNegIntegerField import NonNegIntegerField
from otlmow_model.OtlmowModel.GeometrieTypes.VlakGeometrie import VlakGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Brugligger(ConstructiefObject, VlakGeometrie):
    """Ondersteunende balkstructuur van een brug onder,boven of aansluitend op het brugdek."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Brugligger'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#BekledingComponent', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Inloopbehuizing', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#KabelgeleidingEnLeidingBevestiging', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Kast', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#NietWeggebondenDetectie', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Seinlantaarn', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Ventilatie', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Verkeersbord', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Verlichtingstoestel', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Waarschuwingslantaarn', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#ZenderOntvangerToegang', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Binnenverlichtingstoestel', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#StalenProfiel', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Brugdeel', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Brugdek', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Tegengewichtkist', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#VakwerkElement', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Windverband', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#BetonnenConstructieObject', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#RegelbaarTegengewicht', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#StalenConstructieObject', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#VastTegengewicht', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#LigtOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#ConstructieElement', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#LigtOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Laag', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#LigtOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Oplegging', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#ComplexeGeleiding', direction='i')  # i = direction: incoming

        self._aantalCellen = OTLAttribuut(field=NonNegIntegerField,
                                          naam='aantalCellen',
                                          label='aantal cellen',
                                          objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Brugligger.aantalCellen',
                                          definition='Het aantal cellen van de kokerligger (indien het gaat om een kokerligger).',
                                          owner=self)

        self._detailplanBrugligger = OTLAttribuut(field=DtcDocument,
                                                  naam='detailplanBrugligger',
                                                  label='detailplan brugligger',
                                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Brugligger.detailplanBrugligger',
                                                  definition='Tekening of plan van de brugligger. Deze omvat o.a. ook afmetingen,...',
                                                  owner=self)

        self._type = OTLAttribuut(field=KlTypeBrugligger,
                                  naam='type',
                                  label='type',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Brugligger.type',
                                  definition='Het type van brugligger.',
                                  owner=self)

        self._typeDoorsnede = OTLAttribuut(field=KlTypeDoorsnede,
                                           naam='typeDoorsnede',
                                           label='type doorsnede',
                                           objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Brugligger.typeDoorsnede',
                                           definition='Het type doorsnede van de brugligger.',
                                           owner=self)

    @property
    def aantalCellen(self) -> int:
        """Het aantal cellen van de kokerligger (indien het gaat om een kokerligger)."""
        return self._aantalCellen.get_waarde()

    @aantalCellen.setter
    def aantalCellen(self, value):
        self._aantalCellen.set_waarde(value, owner=self)

    @property
    def detailplanBrugligger(self) -> DtcDocumentWaarden:
        """Tekening of plan van de brugligger. Deze omvat o.a. ook afmetingen,..."""
        return self._detailplanBrugligger.get_waarde()

    @detailplanBrugligger.setter
    def detailplanBrugligger(self, value):
        self._detailplanBrugligger.set_waarde(value, owner=self)

    @property
    def type(self) -> str:
        """Het type van brugligger."""
        return self._type.get_waarde()

    @type.setter
    def type(self, value):
        self._type.set_waarde(value, owner=self)

    @property
    def typeDoorsnede(self) -> str:
        """Het type doorsnede van de brugligger."""
        return self._typeDoorsnede.get_waarde()

    @typeDoorsnede.setter
    def typeDoorsnede(self, value):
        self._typeDoorsnede.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.Abstracten.ConstructieElementAanvaarbeschermingGeleidewerk import ConstructieElementAanvaarbeschermingGeleidewerk
from ...Classes.Abstracten.ConstructiefObject import ConstructiefObject
from ...Datatypes.KlTypeVakwerkElement import KlTypeVakwerkElement
from otlmow_model.OtlmowModel.GeometrieTypes.VlakGeometrie import VlakGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class VakwerkElement(ConstructieElementAanvaarbeschermingGeleidewerk, ConstructiefObject, VlakGeometrie):
    """Element dat deel uitmaakt van een constructie waarbij balken en staven,volgens een stelsel van rechthoeken en/of driehoeken,aan de uiteinden en/of kruiselings verbonden worden tot een onwrikbaar geheel."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/installatie#VakwerkElement'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#BekledingComponent', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Inloopbehuizing', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#KabelgeleidingEnLeidingBevestiging', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Kast', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#NietWeggebondenDetectie', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Seinlantaarn', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Ventilatie', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Verkeersbord', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Verlichtingstoestel', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Waarschuwingslantaarn', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#ZenderOntvangerToegang', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Binnenverlichtingstoestel', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#StalenProfiel', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Balk', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Brugdeel', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Brugdek', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Brugligger', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Hameipoort', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Hameistijl', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Hefportiek', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Heftoren', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Kolom', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Windverband', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#BetonnenConstructieObject', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#StalenConstructieObject', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#LigtOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#ConstructieElement', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#LigtOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Laag', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#ComplexeGeleiding', direction='i')  # i = direction: incoming

        self._typeVakwerkElement = OTLAttribuut(field=KlTypeVakwerkElement,
                                                naam='typeVakwerkElement',
                                                label='type vakwerk-element',
                                                objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#VakwerkElement.typeVakwerkElement',
                                                definition='Het type van vakwerk-element.',
                                                owner=self)

    @property
    def typeVakwerkElement(self) -> str:
        """Het type van vakwerk-element."""
        return self._typeVakwerkElement.get_waarde()

    @typeVakwerkElement.setter
    def typeVakwerkElement(self, value):
        self._typeVakwerkElement.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.Abstracten.Constructiehoofd import Constructiehoofd
from ...Classes.ImplementatieElement.AIMNaamObject import AIMNaamObject
from ...Datatypes.KlHoofdtype import KlHoofdtype


# Generated with OTLClassCreator. To modify: extend, do not edit
class Sluishoofd(Constructiehoofd, AIMNaamObject):
    """Constructiehoofd van een sluis waarin één of meerdere sluisdeuren zitten."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Sluishoofd'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#AanhorigheidSluisStuw', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#ConstructieElementSluisStuw', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Grondkeringen', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#UitsparingSluisdeur', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Deurloop', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Drempel', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Vloernis', direction='i')  # i = direction: incoming

        self._typeHoofd = OTLAttribuut(field=KlHoofdtype,
                                       naam='typeHoofd',
                                       label='type Hoofd',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Sluishoofd.typeHoofd',
                                       definition='Geeft het type hoofd aan van het constructiehoofd.',
                                       owner=self)

    @property
    def typeHoofd(self) -> str:
        """Geeft het type hoofd aan van het constructiehoofd."""
        return self._typeHoofd.get_waarde()

    @typeHoofd.setter
    def typeHoofd(self, value):
        self._typeHoofd.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlNeerslagsensorType(KeuzelijstField):
    """Het type van de neerslagsensor."""
    naam = 'KlNeerslagsensorType'
    label = 'Neerslagsensor type'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlNeerslagsensorType'
    definition = 'Het type van de neerslagsensor.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlNeerslagsensorType'
    options = {
        'capacitief': KeuzelijstWaarde(invulwaarde='capacitief',
                                       label='capacitief',
                                       status='ingebruik',
                                       definitie='Een type sensor dat neerslag (sneeuw, regen, hagel) detecteert door veranderingen in de elektrische capaciteit op te merken. Wanneer neerslag (sneeuw, regen, hagel) op het sensoroppervlak komt, verandert de capaciteit door de aanwezigheid van deze neerslag, wat wordt gedetecteerd door de sensor.',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNeerslagsensorType/capacitief'),
        'optisch': KeuzelijstWaarde(invulwaarde='optisch',
                                    label='optisch',
                                    status='ingebruik',
                                    definitie='Detecteert neerslag (sneeuw, regen, hagel) door licht te gebruiken. Wanneer bv. regendruppels op het oppervlak van de sensor vallen, verstrooien ze het licht, wat de sensor registreert als een verandering in de lichtintensiteit. Deze verstrooiing of vermindering van licht geeft aan dat er neerslag aanwezig is.',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNeerslagsensorType/optisch'),
        'radar': KeuzelijstWaarde(invulwaarde='radar',
                                  label='radar',
                                  status='ingebruik',
                                  definitie='Detecteert neerslag (sneeuw, regen, hagel) door gebruik te maken van radartechnologie. Dit type sensor zendt radargolven uit en analyseert de reflectie van deze golven op vallende neerslag.',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNeerslagsensorType/radar')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.ImplementatieElement.AIMNaamObject import AIMNaamObject
from otlmow_model.OtlmowModel.BaseClasses.BooleanField import BooleanField
from ...Datatypes.KwantWrdInBar import KwantWrdInBar, KwantWrdInBarWaarden
from ...Datatypes.KwantWrdInKiloNewton import KwantWrdInKiloNewton, KwantWrdInKiloNewtonWaarden
from otlmow_model.OtlmowModel.GeometrieTypes.PuntGeometrie import PuntGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class HydraulischeCilinder(AIMNaamObject, PuntGeometrie):
    """Hydraulisch aangedreven actuator waarbij de beweging wordt bewerkstelligd door een inwendige hydraulische druk."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/installatie#HydraulischeCilinder'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Cilinderzuiger', direction='i')  # i = direction: incoming

        self._heeftHijsogen = OTLAttribuut(field=BooleanField,
                                           naam='heeftHijsogen',
                                           label='heeft hijsogen',
                                           objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#HydraulischeCilinder.heeftHijsogen',
                                           definition='Geeft aan of de cilinder hijsogen heeft.',
                                           owner=self)

        self._heeftStandmeting = OTLAttribuut(field=BooleanField,
                                              naam='heeftStandmeting',
                                              label='heeft standmeting',
                                              objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#HydraulischeCilinder.heeftStandmeting',
                                              definition='Geeft aan of de cilinder een inwendige standmeting heeft.',
                                              owner=self)

        self._heeftTegenstang = OTLAttribuut(field=BooleanField,
                                             naam='heeftTegenstang',
                                             label='heeft tegenstang',
                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#HydraulischeCilinder.heeftTegenstang',
                                             definition="Geeft aan of de cilinder voorzien is van een tegenstang. In zo'n geval bevindt er zich een stang aan beide kanten van de zuiger.",
                                             owner=self)

        self._maximaleWerkdruk = OTLAttribuut(field=KwantWrdInBar,
                                              naam='maximaleWerkdruk',
                                              label='maximale werkdruk',
                                              objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#HydraulischeCilinder.maximaleWerkdruk',
                                              definition='De druk die overeenstemt met de maximale ijkingsdruk van de veiligheidskleppen; is gelijk aan 1,10 maal de grootste waarde van de nominale en van de uitzonderlijke druk.',
                                              owner=self)

        self._nominaleDruk = OTLAttribuut(field=KwantWrdInBar,
                                          naam='nominaleDruk',
                                          label='nominale druk',
                                          objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#HydraulischeCilinder.nominaleDruk',
                                          definition='De druk die overeenstemt met de nominale kracht.',
                                          owner=self)

        self._nominaleKracht = OTLAttribuut(field=KwantWrdInKiloNewton,
                                            naam='nominaleKracht',
                                            label='nominale kracht',
                                            objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#HydraulischeCilinder.nominaleKracht',
                                            definition='De kracht die overeenstemt met belastingsniveau 1, volgend uit de belastingscombinatie 1 van het SB270.',
                                            owner=self)

        self._proefdruk = OTLAttribuut(field=KwantWrdInBar,
                                       naam='proefdruk',
                                       label='proefdruk',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#HydraulischeCilinder.proefdruk',
                                       definition='De druk die gelijk is aan 1,50 maal de maximale werkdruk.',
                                       owner=self)

    @property
    def heeftHijsogen(self) -> bool:
        """Geeft aan of de cilinder hijsogen heeft."""
        return self._heeftHijsogen.get_waarde()

    @heeftHijsogen.setter
    def heeftHijsogen(self, value):
        self._heeftHijsogen.set_waarde(value, owner=self)

    @property
    def heeftStandmeting(self) -> bool:
        """Geeft aan of de cilinder een inwendige standmeting heeft."""
        return self._heeftStandmeting.get_waarde()

    @heeftStandmeting.setter
    def heeftStandmeting(self, value):
        self._heeftStandmeting.set_waarde(value, owner=self)

    @property
    def heeftTegenstang(self) -> bool:
        """Geeft aan of de cilinder voorzien is van een tegenstang. In zo'n geval bevindt er zich een stang aan beide kanten van de zuiger."""
        return self._heeftTegenstang.get_waarde()

    @heeftTegenstang.setter
    def heeftTegenstang(self, value):
        self._heeftTegenstang.set_waarde(value, owner=self)

    @property
    def maximaleWerkdruk(self) -> KwantWrdInBarWaarden:
        """De druk die overeenstemt met de maximale ijkingsdruk van de veiligheidskleppen; is gelijk aan 1,10 maal de grootste waarde van de nominale en van de uitzonderlijke druk."""
        return self._maximaleWerkdruk.get_waarde()

    @maximaleWerkdruk.setter
    def maximaleWerkdruk(self, value):
        self._maximaleWerkdruk.set_waarde(value, owner=self)

    @property
    def nominaleDruk(self) -> KwantWrdInBarWaarden:
        """De druk die overeenstemt met de nominale kracht."""
        return self._nominaleDruk.get_waarde()

    @nominaleDruk.setter
    def nominaleDruk(self, value):
        self._nominaleDruk.set_waarde(value, owner=self)

    @property
    def nominaleKracht(self) -> KwantWrdInKiloNewtonWaarden:
        """De kracht die overeenstemt met belastingsniveau 1, volgend uit de belastingscombinatie 1 van het SB270."""
        return self._nominaleKracht.get_waarde()

    @nominaleKracht.setter
    def nominaleKracht(self, value):
        self._nominaleKracht.set_waarde(value, owner=self)

    @property
    def proefdruk(self) -> KwantWrdInBarWaarden:
        """De druk die gelijk is aan 1,50 maal de maximale werkdruk."""
        return self._proefdruk.get_waarde()

    @proefdruk.setter
    def proefdruk(self, value):
        self._proefdruk.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlBestrijkingProductfamilie(KeuzelijstField):
    """De mogelijke productfamiles."""
    naam = 'KlBestrijkingProductfamilie'
    label = 'Productfamilies'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlBestrijkingProductfamilie'
    definition = 'De mogelijke productfamiles.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlBestrijkingProductfamilie'
    options = {
        '1': KeuzelijstWaarde(invulwaarde='1',
                              label='1',
                              status='ingebruik',
                              definitie='Productfamilie 1',
                              objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBestrijkingProductfamilie/1'),
        '2': KeuzelijstWaarde(invulwaarde='2',
                              label='2',
                              status='ingebruik',
                              definitie='Productfamilie 2',
                              objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBestrijkingProductfamilie/2'),
        '3': KeuzelijstWaarde(invulwaarde='3',
                              label='3',
                              status='ingebruik',
                              definitie='Productfamilie 3',
                              objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBestrijkingProductfamilie/3'),
        '4': KeuzelijstWaarde(invulwaarde='4',
                              label='4',
                              status='ingebruik',
                              definitie='Productfamilie 4',
                              objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBestrijkingProductfamilie/4'),
        '5': KeuzelijstWaarde(invulwaarde='5',
                              label='5',
                              status='ingebruik',
                              definitie='Productfamilie 5',
                              objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBestrijkingProductfamilie/5'),
        '6': KeuzelijstWaarde(invulwaarde='6',
                              label='6',
                              status='ingebruik',
                              definitie='Productfamilie 6',
                              objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBestrijkingProductfamilie/6'),
        '7': KeuzelijstWaarde(invulwaarde='7',
                              label='7',
                              status='ingebruik',
                              definitie='Productfamilie 7',
                              objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBestrijkingProductfamilie/7'),
        '8': KeuzelijstWaarde(invulwaarde='8',
                              label='8',
                              status='ingebruik',
                              definitie='Productfamilie 8',
                              objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBestrijkingProductfamilie/8')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.ImplementatieElement.AIMNaamObject import AIMNaamObject
from otlmow_model.OtlmowModel.BaseClasses.BooleanField import BooleanField
from ...Datatypes.KlVWCTypeNivelleringssysteem import KlVWCTypeNivelleringssysteem
from otlmow_model.OtlmowModel.GeometrieTypes.VlakGeometrie import VlakGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class VasteWaterbouwkundigeConstructie(AIMNaamObject, VlakGeometrie):
    """Statische bouwkundige constructie in of aan een waterloop al dan niet in combinatie met een beweegbare waterkerende constructie, om grond en een waterpeilverschil te keren."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/installatie#VasteWaterbouwkundigeConstructie'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#AanhorigheidSluisStuw', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Constructiehoofd', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Kabelkoker', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Kolk', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Omloopriool', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Sluis', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Stuw', direction='o')  # o = direction: outgoing

        self._heeftPompput = OTLAttribuut(field=BooleanField,
                                          naam='heeftPompput',
                                          label='heeft pompput',
                                          objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#VasteWaterbouwkundigeConstructie.heeftPompput',
                                          definition='Geeft aan of de vaste waterbouwkundige constructie een pompput heeft.',
                                          owner=self)

        self._heeftWoelkamer = OTLAttribuut(field=BooleanField,
                                            naam='heeftWoelkamer',
                                            label='heeft woelkamer',
                                            objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#VasteWaterbouwkundigeConstructie.heeftWoelkamer',
                                            definition='Geeft aan of er al dan niet een woelkamer aanwezig is in de vaste waterbouwkundige constructie.',
                                            owner=self)

        self._typeNivelleringssysteem = OTLAttribuut(field=KlVWCTypeNivelleringssysteem,
                                                     naam='typeNivelleringssysteem',
                                                     label='type nivelleringssysteem',
                                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#VasteWaterbouwkundigeConstructie.typeNivelleringssysteem',
                                                     definition='Verwijst naar het type systeem dat gebruikt wordt voor de nivellering in vaste waterbouwkundige constructies.',
                                                     owner=self)

    @property
    def heeftPompput(self) -> bool:
        """Geeft aan of de vaste waterbouwkundige constructie een pompput heeft."""
        return self._heeftPompput.get_waarde()

    @heeftPompput.setter
    def heeftPompput(self, value):
        self._heeftPompput.set_waarde(value, owner=self)

    @property
    def heeftWoelkamer(self) -> bool:
        """Geeft aan of er al dan niet een woelkamer aanwezig is in de vaste waterbouwkundige constructie."""
        return self._heeftWoelkamer.get_waarde()

    @heeftWoelkamer.setter
    def heeftWoelkamer(self, value):
        self._heeftWoelkamer.set_waarde(value, owner=self)

    @property
    def typeNivelleringssysteem(self) -> str:
        """Verwijst naar het type systeem dat gebruikt wordt voor de nivellering in vaste waterbouwkundige constructies."""
        return self._typeNivelleringssysteem.get_waarde()

    @typeNivelleringssysteem.setter
    def typeNivelleringssysteem(self, value):
        self._typeNivelleringssysteem.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlLETrottoirbandVorm(KeuzelijstField):
    """De vormen van een trottoirband."""
    naam = 'KlLETrottoirbandVorm'
    label = 'Trottoirband vorm'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlLETrottoirbandVorm'
    definition = 'De vormen van een trottoirband.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlLETrottoirbandVorm'
    options = {
        'afgeschuind': KeuzelijstWaarde(invulwaarde='afgeschuind',
                                        label='afgeschuind',
                                        status='ingebruik',
                                        definitie='Afgeschuind',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLETrottoirbandVorm/afgeschuind'),
        'niet-afgeschuind': KeuzelijstWaarde(invulwaarde='niet-afgeschuind',
                                             label='niet afgeschuind',
                                             status='ingebruik',
                                             definitie='niet afgeschuind',
                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLETrottoirbandVorm/niet-afgeschuind')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlSleufUitvoering(KeuzelijstField):
    """Uitvoeringen van de sleuf."""
    naam = 'KlSleufUitvoering'
    label = 'Sleuf uitvoering'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlSleufUitvoering'
    definition = 'Uitvoeringen van de sleuf.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlSleufUitvoering'
    options = {
        'beschoeide-sleuf': KeuzelijstWaarde(invulwaarde='beschoeide-sleuf',
                                             label='beschoeide sleuf',
                                             status='ingebruik',
                                             definitie='beschoeide sleuf',
                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSleufUitvoering/beschoeide-sleuf'),
        'beschoeide-sleuf-met-voorafgraving': KeuzelijstWaarde(invulwaarde='beschoeide-sleuf-met-voorafgraving',
                                                               label='beschoeide sleuf met voorafgraving',
                                                               status='ingebruik',
                                                               definitie='beschoeide sleuf met voorafgraving',
                                                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSleufUitvoering/beschoeide-sleuf-met-voorafgraving'),
        'directional-drilling': KeuzelijstWaarde(invulwaarde='directional-drilling',
                                                 label='directional drilling',
                                                 status='ingebruik',
                                                 definitie='directional drilling',
                                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSleufUitvoering/directional-drilling'),
        'onderdoorpersing': KeuzelijstWaarde(invulwaarde='onderdoorpersing',
                                             label='onderdoorpersing',
                                             status='ingebruik',
                                             definitie='onderdoorpersing',
                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSleufUitvoering/onderdoorpersing'),
        'open-sleuf': KeuzelijstWaarde(invulwaarde='open-sleuf',
                                       label='open sleuf',
                                       status='ingebruik',
                                       definitie='open sleuf',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSleufUitvoering/open-sleuf'),
        'waterdicht-beschoeide-sleuf-met-damplanken': KeuzelijstWaarde(invulwaarde='waterdicht-beschoeide-sleuf-met-damplanken',
                                                                       label='waterdicht beschoeide sleuf met damplanken',
                                                                       status='ingebruik',
                                                                       definitie='waterdicht beschoeide sleuf met damplanken',
                                                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSleufUitvoering/waterdicht-beschoeide-sleuf-met-damplanken')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from ...Classes.Abstracten.Energiemeter import Energiemeter


# Generated with OTLClassCreator. To modify: extend, do not edit
class EnergiemeterDerden(Energiemeter):
    """Toestel dat eigendom is van een derde partij, verschillend van de distributienetbeheerder, waarmee het energieverbruik van de installaties van deze derden gemeten wordt. Deze energiemeters komen enkel voor op: - installaties van AWV waarop derden een afzonderlijke kring hebben gekregen voor het voeden van hun eigen installaties - installaties van derden waarop AWV een afzonderlijke kring heeft gekregen voor het voeden van onze installaties"""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#EnergiemeterDerden'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Laagspanningsbord', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#IsInspectieVan', target='https://wegenenverkeer.data.vlaanderen.be/ns/proefenmeting#MeteropnameEnergiemeter', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voedt', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Hoofdschakelaar', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voedt', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#VoedingDerdenLaagspanning', direction='i')  # i = direction: incoming
